package com.gic.finance.service;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.finance.dto.CashWithdrawalDTO;
import com.gic.finance.dto.OperationUserInfoDTO;
import com.gic.finance.qo.CashWithdrawalQueryListQO;

/**
 * 提现管理
 * @ClassName: CashWithdrawalApiService 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/29 4:24 PM 
 */
public interface CashWithdrawalApiService {
    /**
     * 提现申请--服务商
     * @Title: save 
     * @Description:
      * @author guojuxing
     * @param dto 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.String> 提现申请单号
      */
    ServiceResponse<String> cashWithdrawalOfServiceProvider(CashWithdrawalDTO dto);

    /**
     * 提现申请--供应商
     * @Title: save 
     * @Description:
      * @author guojuxing
     * @param dto 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.String> 提现申请单号
      */
    ServiceResponse<String> cashWithdrawalOfSupplier(CashWithdrawalDTO dto);

    /**
     * 填写物流信息
     * @Title: expressMail 
     * @Description:
     * @author guojuxing
     * @param serialNumber 提现申请流水号
     * @param expressMailName 物流公司
     * @param expressMailNumber 物流单号
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
     */
    ServiceResponse<Void> expressMail(String serialNumber, String expressMailName, String expressMailNumber);

    /**
     * 审核通过
     * @Title: approval 
     * @Description:
      * @author guojuxing
     * @param id 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> approval(Integer id, OperationUserInfoDTO dto);

    /**
     * 详情
     * @Title: getDetail 
     * @Description:
      * @author guojuxing
     * @param id 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.finance.dto.CashWithdrawalDTO> 
      */
    ServiceResponse<CashWithdrawalDTO> getDetail(Integer id);

    /**
     * 驳回
     * @Title: reject 
     * @Description:
      * @author guojuxing
     * @param id 主键
     * @param rejectReason  驳回理由
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> reject(Integer id, String rejectReason, OperationUserInfoDTO dto);

    /**
     * 打款
     * @Title: pay 
     * @Description:
      * @author guojuxing
     * @param id 申请单主键第
     * @param payId 打款户信息ID
     * @param bankSerialNumber  银行转账流水号
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> pay(Integer id, Integer payId, String bankSerialNumber);

    /**
     * 分页查询
     * @Title: listCashWithdrawalPage 
     * @Description: 
      * @author guojuxing 
     * @param params 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.finance.dto.CashWithdrawalDTO>> 
      */
    ServiceResponse<Page<CashWithdrawalDTO>> listCashWithdrawalPage(CashWithdrawalQueryListQO params);
}
